/*=========================================================================

  Program: GDCM (Grassroots DICOM). A DICOM library
  Module:  $URL$

  Copyright (c) 2006-2010 Mathieu Malaterre
  All rights reserved.
  See Copyright.txt or http://gdcm.sourceforge.net/Copyright.html for details.

     This software is distributed WITHOUT ANY WARRANTY; without even
     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
     PURPOSE.  See the above copyright notice for more information.

=========================================================================*/
#ifndef GDCMSERIES_H
#define GDCMSERIES_H

#include "gdcmTypes.h"

namespace gdcm
{
/**
 * \brief Series
 */
class GDCM_EXPORT Series
{
public:
  Series() { 
  }
private:
  // Image, Waveform...
};

} // end namespace gdcm

#endif //GDCMSERIES_H
